<?php
// File to force Dolibarr wizard installer choices.
//
// This file must be present as /etc/dolibarr/install.forced.php
// during install process to be used.

$force_install_packager='deb';
$force_install_noedit=2;
$force_install_message='KeepDefaultValuesDeb';
$force_install_main_data_root='/var/lib/dolibarr/documents';
$force_install_type='mysqli';
$force_install_dbserver='';
$force_install_port='3306';
$force_install_database='dolibarr';
$force_install_createdatabase='1';
$force_install_databaselogin='dolibarr';
$force_install_databasepass='';
$force_install_createuser='1';
$force_install_dolibarrlogin='admin';
$force_install_nophpinfo='1';
$force_install_lockinstall='444';

# Retrieve credentials prepared by the package's postinst
if (file_exists('/etc/dolibarr/mysql-credentials.php'))
    include('/etc/dolibarr/mysql-credentials.php');

# Retrieve the default paths used by the package
if (file_exists('/etc/dolibarr/default-paths.php')) {
    include('/etc/dolibarr/default-paths.php');
    # PHP libraries
    $force_dolibarr_lib_ADODB_PATH = $dolibarr_lib_ADODB_PATH;
    $force_dolibarr_lib_FPDF_PATH = $dolibarr_lib_FPDF_PATH;
    $force_dolibarr_lib_FPDI_PATH = $dolibarr_lib_FPDI_PATH;
    $force_dolibarr_lib_GEOIP_PATH = $dolibarr_lib_GEOIP_PATH;
    $force_dolibarr_lib_NUSOAP_PATH = $dolibarr_lib_NUSOAP_PATH;
    $force_dolibarr_lib_ODTPHP_PATH = $dolibarr_lib_ODTPHP_PATH;
    $force_dolibarr_lib_ODTPHP_PATHTOPCLZIP = $dolibarr_lib_ODTPHP_PATHTOPCLZIP;
    $force_dolibarr_lib_PHPEXCEL_PATH = $dolibarr_lib_PHPEXCEL_PATH;
    $force_dolibarr_lib_TCPDF_PATH = $dolibarr_lib_TCPDF_PATH;
    # Javascript libraries
    $force_dolibarr_js_CKEDITOR = $dolibarr_js_CKEDITOR;
    $force_dolibarr_js_JQUERY = $dolibarr_js_JQUERY;
    $force_dolibarr_js_JQUERY_UI = $dolibarr_js_JQUERY_UI;
    $force_dolibarr_js_JQUERY_FLOT = $dolibarr_js_JQUERY_FLOT;
    # Fonts
    $force_dolibarr_font_DOL_DEFAULT_TTF = $dolibarr_font_DOL_DEFAULT_TTF;
    $force_dolibarr_font_DOL_DEFAULT_TTF_BOLD = $dolibarr_font_DOL_DEFAULT_TTF_BOLD;
}
?>
